Index: wp-admin/includes/post.php
IDEA additional info:
Subsystem: com.intellij.openapi.diff.impl.patch.CharsetEP
<+>UTF-8
===================================================================
--- wp-admin/includes/post.php	(revision 39414)
+++ wp-admin/includes/post.php	(revision )
@@ -1155,7 +1155,7 @@
 }
 
 /**
  * Filter the SQL clauses of an attachment query to include filenames.
  *
  * @since 4.7.0
  * @access private
@@ -1171,7 +1171,7 @@
 	remove_filter( 'posts_clauses', __FUNCTION__ );
 
 	// Add a LEFT JOIN of the postmeta table so we don't trample existing JOINs.
-	$clauses['join'] .= " LEFT JOIN {$wpdb->postmeta} AS sq1 ON ( {$wpdb->posts}.ID = sq1.post_id AND sq1.meta_key = '_wp_attached_file' )";
+	$clauses['join'] .= " LEFT JOIN {$wpdb->postmeta} AS sq1 ON ( {$wpdb->posts}.ID = sq1.post_id AND sq1.meta_key = '_wp_attached_file' AND sq1.meta_key = '_wp_attachment_image_alt' )";
 
 	$clauses['groupby'] = "{$wpdb->posts}.ID";
 
@@ -1155,7 +1155,7 @@
 
 /**
- * Filter the SQL clauses of an attachment query to include filenames.
+ * Filter the SQL clauses of an attachment query to include filenames and alt tag.
  *
  * @since 4.7.0
